@@ -18,7 +18,7 @@ def create(
         "email": userID,
     }
 
-    data = json.dumps({
+    body = json.dumps({
         "uploadType": uploadType,
         "shot": shot,
         "resourceId": resourceId,
@@ -27,7 +27,7 @@ def create(
         "resourceName": resourceName
     })
 
-    response = requests.post(f"{url_path}", headers=headers, data=data) 
+    response = requests.post(f"{url_path}", headers=headers, data=body) 
     data = json.loads(response.content)
     
     print("{:<15} {:<5}".format("ID", "Status"))
